@@ -11,7 +11,7 @@ use Time::Local;
 use parent 'Exporter';
 use integer;    # Integer math, so we don't need floor
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 our @ISA = qw(Exporter);
 our %EXPORT_TAGS = (
@@ -465,6 +465,10 @@ Thanks to Niel Bowers for [rt.cpan.org #93599] Not clear what type of week numbe
 
 =head1 Log
 
+Revision 1.7  2020/01/04 Greg
+ - Resolved issue with tests failing. Now pass the full 4 digit year to timelocal() to avoid ambigous date values.
+ - No changes to the actual code
+
 Revision 1.6  2014/04/09 Greg
  - Allow extended date coverage - past dates handled by localtime - using hash ref argument year, month, day
  - Added mode for ISO 8601 output YYYY-Wxx
